========================
Neo 0.13.2 release notes
========================

30th July 2024

This release of Neo contains bug fixes, still with a focus on the planned 1.0 release,
along with some performance improvements in IO modules and updates to the CI.

See all `pull requests`_ included in this release and the `list of closed issues`_.


Continuous Integration
----------------------

Core tests now run on python 3.12.

IO tests now run on python 3.9 and python 3.11.


Performance Improvements & Code quality
---------------------------------------

The imports across the code base were standardized to standard library, 3rd party,
and then 1st party for top level imports.

Additionally, :code:`neo` import time was improved.


Bug fixes and improvements in IO modules
----------------------------------------

Bug fixes and/or improvements have been made to :class:`IntanIO`, :class:`PlexonIO`, :class:`SpikeGadgetsIO`,
:class:`NeuralynxIO`, :class:`SpikeGLXIO`, :class:`BlackrockIO`, and :class:`RawBinarySignalRawIO`.

Acknowledgements
----------------

Thanks to Heberto Mayorquin, Zach McKenzie, Alessio Buccino, Andrew Davison, Chris Heydrick, 
Anthony Pinto, Kyu Hun Lee, Téo Lohrer, Tom Donoghue, Xin Niu, and Samuel Garcia for their
contributions to this release.

.. _`pull requests`: https://github.com/NeuralEnsemble/python-neo/pulls?q=is%3Apr+is%3Aclosed+milestone%3A0.13.2

.. _`list of closed issues`: https://github.com/NeuralEnsemble/python-neo/issues?q=is%3Aissue+is%3Aclosed+milestone%3A0.13.2